netapp_ontap.models.node_metrics_response_records API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.node_metrics_response_records`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class NodeMetricsResponseRecordsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the NodeMetricsResponseRecords object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `duration: str GET POST PATCH`

    The duration over which this sample is calculated. The time durations are represented in the ISO-8601 standard format. Samples can be calculated over the following durations:

    Valid choices:

    - PT15S
    - PT5M
    - PT30M
    - PT2H
    - P1D
  `links: SelfLink GET`

    The links field of the node_metrics_response_records.

  `processor_utilization: Size GET POST PATCH`

    Average CPU Utilization for the node

    Example: 13

  `status: str GET POST PATCH`

    Errors associated with the sample. For example, if the aggregation of data over multiple nodes fails, then any partial errors might return "ok" on success or "error" on an internal uncategorized failure. Whenever a sample collection is missed but done at a later time, it is back filled to the previous 15 second timestamp and tagged with "backfilled_data". "inconsistent_delta_time" is encountered when the time between two collections is not the same for all nodes. Therefore, the aggregated value might be over or under inflated. "Negative_delta" is returned when an expected monotonically increasing value has decreased in value. "inconsistent_old_data" is returned when one or more nodes do not have the latest data.

    Valid choices:

    - ok
    - error
    - partial_no_data
    - partial_no_uuid
    - partial_no_response
    - partial_other_error
    - negative_delta
    - backfilled_data
    - inconsistent_delta_time
    - inconsistent_old_data
  `timestamp: ImpreciseDateTime GET POST PATCH`

    The timestamp of the performance data.

    Example: 2017-01-25T11:20:13.000+0000

  `uuid: str GET POST PATCH`

    The uuid field of the node_metrics_response_records.

    Example: 1cd8a442-86d1-11e0-ae1c-123478563412